
Special functions
=================

These functions are used with rotations or attitudes to transform, interpolate,
re-define, or otherwise modify the attitude representations.

.. toctree::
   :caption: Interpolation
   :titlesonly:
   :maxdepth: 1

   funSLERP

.. toctree::
   :caption: Methods to obtain Quaternions from Direction Cosine Matrices
   :titlesonly:
   :maxdepth: 1

   Hughes
   Chiaverini
   Sarabandi
   Itzhack
   Shepperd

.. toctree::
   :caption: Other
   :titlesonly:
   :maxdepth: 1

   random_attitudes
